@@ -100,7 +100,7 @@ LearnerClassifCVGlmnet = R6Class("LearnerClassifCVGlmnet",
 
   private = list(
     .train = function(task) {
-      data = as.matrix(task$data(cols = task$feature_names))
+      data = as_numeric_matrix(task$data(cols = task$feature_names))
       target = swap_levels(task$truth())
       pv = self$param_set$get_values(tags = "train")
       pv$family = ifelse(length(task$class_names) == 2L, "binomial", "multinomial")
@@ -112,7 +112,7 @@ LearnerClassifCVGlmnet = R6Class("LearnerClassifCVGlmnet",
     },
 
     .predict = function(task) {
-      newdata = as.matrix(ordered_features(task, self))
+      newdata = as_numeric_matrix(ordered_features(task, self))
       pv = self$param_set$get_values(tags = "predict")
       pv = rename(pv, "predict.gamma", "gamma")
 
